@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "matlab-mode" "8.1.1"
+(define-package "matlab-mode" "20251016.2044"
   "Major mode for MATLAB(R) dot-m files."
   '((emacs "27.2"))
   :url "https://github.com/mathworks/Emacs-MATLAB-Mode"
-  :commit "e6923314f3ffb291e45ece6b1ce08a0961e31adb"
-  :revdesc "e6923314f3ff"
+  :commit "33673b5b7caf56f064108af5a39b9fadba02ac31"
+  :revdesc "33673b5b7caf"
   :keywords '("matlab(r)")
   :authors '(("Matt Wette" . "mwette@alumni.caltech.edu")
              ("Eric M. Ludlam" . "eludlam@mathworks.com"))
